class Base {
    private p__0;
}
var x338 = (n__2: {
    () : Base[];
})=>n__2
;
x338(function named__3() {
    return [
        d1,
        d2
    ];
});
